==> nextcloud-15.0.5p1.tgz: nextcloud/apps/comments/l10n/eo.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentoj",
    "You commented" : "Vi komentis",
    "%1$s commented" : "%1$s komentis",
    "{author} commented" : "{author} komentis",
    "You commented on %1$s" : "Vi komentis %1$s",
    "You commented on {file}" : "Vi komentis pri {file}",
    "%1$s commented on %2$s" : "%1$s komentis %2$s",
    "{author} commented on {file}" : "{author} komentis pri {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentoj</strong> por dosieroj",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Vi estis menciita en „{file}“, en komento de uzanto, kiu ekde tiam estis forigita",
    "{user} mentioned you in a comment on “{file}”" : "{user} menciis vin en komento pri „{file}“",
    "Files app plugin to add comments to files" : "Kromprogramo por la aplikaĵo „Dosieroj“ por aldoni komentojn al dosieroj",
    "Edit comment" : "Redakti komenton",
    "Delete comment" : "Forigi komenton",
    "New comment …" : "Nova komento …",
    "Post" : "Afiŝi",
    "Cancel" : "Nuligi",
    "[Deleted user]" : "[Forigita uzanto]",
    "No comments yet, start the conversation!" : "Neniu komento, ekkonversaciu!",
    "More comments …" : "Pli da komentoj...",
    "Save" : "Konservi",
    "Allowed characters {count} of {max}" : "{count} el {max} signoj maksimume",
    "Error occurred while retrieving comment with ID {id}" : "Eraro dum ricevo de komento kun identigilo {id}",
    "Error occurred while updating comment with id {id}" : "Eraro dum ĝisdatigo de komento kun identigilo {id}",
    "Error occurred while posting comment" : "Eraro dum sendo de komento",
    "_%n unread comment_::_%n unread comments_" : ["%n nelegataj komentoj","%n nelegataj komentoj"],
    "Comment" : "Komento",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Vi estis menciita en „%s“, en komento de uzanto, kiu ekde tiam estis forigita",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s menciis vin en komento pri „%2$s“"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/comments/l10n/eo.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentoj",
    "You commented" : "Vi komentis",
    "%1$s commented" : "%1$s komentis",
    "{author} commented" : "{author} komentis",
    "You commented on %1$s" : "Vi komentis %1$s",
    "You commented on {file}" : "Vi komentis pri {file}",
    "%1$s commented on %2$s" : "%1$s komentis %2$s",
    "{author} commented on {file}" : "{author} komentis pri {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentoj</strong> por dosieroj",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Vi estis menciita en „{file}“, en komento de uzanto, kiu poste estis forigita",
    "{user} mentioned you in a comment on “{file}”" : "{user} menciis vin en komento pri „{file}“",
    "Files app plugin to add comments to files" : "Kromprogramo por la aplikaĵo „Dosieroj“ por aldoni komentojn al dosieroj",
    "Edit comment" : "Redakti komenton",
    "Delete comment" : "Forigi komenton",
    "New comment …" : "Nova komento …",
    "Post" : "Afiŝi",
    "Cancel" : "Nuligi",
    "[Deleted user]" : "[Forigita uzanto]",
    "No comments yet, start the conversation!" : "Neniu komento, ekkonversaciu!",
    "More comments …" : "Pli da komentoj...",
    "Save" : "Konservi",
    "Allowed characters {count} of {max}" : "{count} el {max} signoj maksimume",
    "Error occurred while retrieving comment with ID {id}" : "Eraro dum ricevo de komento kun identigilo {id}",
    "Error occurred while updating comment with id {id}" : "Eraro dum ĝisdatigo de komento kun identigilo {id}",
    "Error occurred while posting comment" : "Eraro dum sendo de komento",
    "_%n unread comment_::_%n unread comments_" : ["%n nelegataj komentoj","%n nelegataj komentoj"],
    "_1 new comment_::_{unread} new comments_" : ["1 nova komento","{unread} novaj komentoj"],
    "Comment" : "Komento"
},
"nplurals=2; plural=(n != 1);");
